var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { LitElement, html, css, property, customElement } from 'lit-element';
import './kai-icon';
import './kai-text';
let KaiInput = class KaiInput extends LitElement {
    constructor() {
        super();
        this.value = '';
        this.maxLength = 400;
        this.inFocus = false;
        this.type = 'text';
        this.placeholder = '';
        this.autofocus = false;
        this.tabIndex = this.tabIndex < 0 ? 0 : this.tabIndex;
    }
    static get styles() {
        return css `
      :host {
        outline: none;
        width: 100%;
      }

      div {
        position: relative;
        display: flex;
        flex-direction: row;
        justify-content: flex-start;
        align-items: center;
        width: 100%;
        max-height: calc(var(--baseline) * 6);
        padding: 1.5rem 0 1.7rem;
      }

      div::after {
        content: '';
        position: absolute;
        left: 0;
        bottom: 1.5rem;
        width: 100%;
        height: 0.2rem;
        background-color: var(--gs-40);
      }

      div.-focus::after {
        background-color: var(--theme-color-primary);
      }

      div.-with-error::after {
        background-color: var(--error-color);
      }

      input {
        display: flex;
        flex: 1;
        width: 100%;
        height: 2.8rem;
        border: none;
        outline: none;
        background: transparent;
        color: var(--gs-100);
        font-size: 1.8rem;
        font-weight: 600;
        overflow: hidden;
        white-space: nowrap;
        text-overflow: ellipsis;
        margin-left: 1rem;
      }

      button {
        background-color: transparent;
        display: flex;
        width: 2.4rem;
        height: 2.4rem;
        border: none;
        color: var(--gs-40);
      }

      label {
        position: absolute;
        top: 1.5rem;
        left: 0;
        width: 100%;
        height: 2.8rem;
        display: flex;
        flex-direction: row;
        justify-content: flex-start;
        color: var(--gs-80);
        font-size: 1.8rem;
        font-weight: 600;
        pointer-events: none;
        transition: all 0.1s;
      }

      label.-filled,
      input:focus + label {
        top: 0;
        height: 1.5rem;
        font-size: 1.2rem;
      }

      input:focus + label {
        color: var(--gs-100);
      }

      div.-with-error label,
      .exclamation,
      .error-message {
        color: var(--error-color);
      }

      .exclamation {
        animation: rotate 0.5s cubic-bezier(0.8, -0.5, 0.2, 1.4) forwards;
      }

      .error-message {
        position: absolute;
        left: 0;
        bottom: 0;
      }

      @keyframes rotate {
        0% {
          opacity: 0;
          transform: rotate(-45deg);
        }
        50% {
          opacity: 1;
        }
        100% {
          opacity: 1;
          transform: rotate(0);
        }
      }
      :host([type="search"]) div {
        padding-inline-start: 3.2rem;
      }

      :host([type="search"]) .search-icon {
        position: absolute;
        left: 0;
        top: 1.5rem;
        color: var(--gs-40);
      }

      :host([type="search"]) div.-focus .search-icon {
        color: var(--gs-100);
      }
      
      .del {
        background-color: var(--gs-00);
      }
    `;
    }
    clear() {
        this.value = '';
        const inputChangeEvent = this.customEvent('change', '');
        this.dispatchEvent(inputChangeEvent);
        this.shadowRoot.getElementById('text-field').focus();
    }
    customEvent(type, value) {
        return new CustomEvent(`input-${type}`, {
            bubbles: true,
            composed: true,
            detail: {
                value,
            },
        });
    }
    handleChange(e) {
        const input = e.target;
        const value = input.value;
        this.value = input.value;
        const inputChangeEvent = this.customEvent('change', value);
        this.dispatchEvent(inputChangeEvent);
    }
    handleFocus({ type, target }) {
        const input = target;
        this.inFocus = type === 'focus';
        const inputFocusEvent = this.customEvent(type, input.value);
        this.dispatchEvent(inputFocusEvent);
    }
    firstUpdated() {
        if (this.autofocus) {
            this.shadowRoot.getElementById('text-field').focus();
        }
    }
    render() {
        let className = this.inFocus ? '-focus' : '';
        className += this.error ? ' -with-error' : '';
        return html `
      <div class="${className}">
        ${this.type === 'search'
            ? html `
                <kai-icon class="search-icon" size="32">search</kai-icon>
            `
            : null}
        <input
          id="text-field"
          .type="${this.type}"
          maxlength="${this.maxLength}"
          .value="${this.value}"
          placeholder="${this.placeholder}"
          @input="${this.handleChange}"
          @focus="${this.handleFocus}"
          @blur="${this.handleFocus}"
        />
        ${this.label
            ? html `
              <label class="${this.value.length ? '-filled' : ''}">
                ${this.label}
              </label>
            `
            : null}
        ${this.value.length
            ? html `
              <button @click="${this.clear}" tabindex="-1">
                <kai-icon class="del">input-clear</kai-icon>
              </button>
            `
            : null}
        ${this.error
            ? html `
              <kai-icon class="exclamation">exclamation</kai-icon>
              <kai-text as="h6" class="error-message">${this.error}</kai-text>
            `
            : null}
      </div>
    `;
    }
};
__decorate([
    property({ type: String, reflect: true })
], KaiInput.prototype, "value", void 0);
__decorate([
    property({ type: Number })
], KaiInput.prototype, "maxLength", void 0);
__decorate([
    property({ type: Boolean, reflect: false })
], KaiInput.prototype, "inFocus", void 0);
__decorate([
    property({ type: String })
], KaiInput.prototype, "type", void 0);
__decorate([
    property({ type: String })
], KaiInput.prototype, "placeholder", void 0);
__decorate([
    property({ type: String })
], KaiInput.prototype, "label", void 0);
__decorate([
    property({ type: Boolean })
], KaiInput.prototype, "autofocus", void 0);
__decorate([
    property({ type: String })
], KaiInput.prototype, "error", void 0);
KaiInput = __decorate([
    customElement('kai-input')
], KaiInput);
export { KaiInput };
//# sourceMappingURL=kai-input.js.map