var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { customElement, LitElement, css, property, html } from 'lit-element';
import { DragNDropService } from './../services';
let KaiItem = class KaiItem extends LitElement {
    constructor() {
        super(...arguments);
        this.mode = 'list';
        this.button = false;
        this.draggable = false;
        this.handleMouseLeave = e => {
            this.classList.remove('over');
        };
        this.handleMouseUp = e => {
            const { isDragging } = DragNDropService;
            if (isDragging) {
                DragNDropService.commit();
                this.classList.remove('top');
                this.classList.remove('over');
            }
            clearTimeout(this.timer);
        };
        this.handleMouseOver = e => {
            const { isDragging, source } = DragNDropService;
            if (isDragging) {
                let item = e.target.closest('kai-item');
                let index = item.dataset.index;
                if (source !== index) {
                    const previousEl = item.previousElementSibling;
                    if (previousEl) {
                        this.classList.add('over');
                        DragNDropService.target = index;
                    }
                }
            }
        };
        this.handleMouseMove = e => {
            const { isDragging, source } = DragNDropService;
            if (isDragging) {
                let item = e.target.closest('kai-item');
                let index = item.dataset.index;
                if (source !== index) {
                    const previousEl = item.previousElementSibling;
                    if (!previousEl) {
                        const dimensions = item.getBoundingClientRect();
                        const middle = dimensions.height / 3;
                        if (e.layerY < middle) {
                            this.classList.add('top');
                            this.classList.remove('over');
                            DragNDropService.target = 'first';
                        }
                        if (e.clientY >= dimensions.top + middle) {
                            this.classList.add('over');
                            this.classList.remove('top');
                            DragNDropService.target = index;
                        }
                    }
                }
            }
        };
        this.timer = null;
        this.checkLongPress = e => {
            this.timer = setTimeout(() => {
                DragNDropService.pressItem(e);
            }, 250);
        };
    }
    static get styles() {
        return css `
      :host {
        display: flex;
        transition: padding 0.4s;
        transition-timing-function: cubic-bezier(0.3, 0, 0.25, 1);
      }

      :host([mode='list']) {
        width: 100%;
        min-height: calc(var(--baseline) * 7);
        flex-direction: row;
        align-items: center;
        background-color: var(--gs-00);
        overflow-x: hidden;
        overflow-y: auto;
      }

      :host([mode='list']) .right,
      :host([mode='list']) .left {
        display: flex;
        justify-content: center;
        align-items: center;
        width: 3.2rem;
        height: 4rem;
        overflow: hidden;
        /* margin-inline-start: calc(var(--baseline) * 2); */
        transition-property: opacity, width;
        transition-duration: 0.12s, 0.24s;
        transition-timing-function: cubic-bezier(0, 0, 0, 1);
      }

      :host([mode='list']) .left:empty {
        width: 0;
        opacity: 0;
        margin-inline-end: 0;
      }

      :host([mode='list']) .left:not(:empty) {
        width: 3.2rem;
        opacity: 1;
        margin-inline-end: calc(var(--baseline) * 1.5);
      }

      :host([mode='list']) .content {
        display: flex;
        flex: 1;
        flex-direction: column;
        align-content: center;
        align-items: flex-start;
        max-width: calc(100% - 4rem);
        color: var(--gs-100);
      }

      :host([mode='list']) .right:empty {
        width: 0;
        opacity: 0;
        margin-inline-end: 0;
      }

      :host([mode='list']) .right:not(:empty) {
        width: 12.5rem;
        opacity: 1;
        margin-inline-end: 0;
      }

      :host([button]) > * {
        pointer-events: none;
      }

      :host([button]) {
        transition: background 0.01s;
      }

      :host([button]:active) {
        background-color: var(--gs-10);
      }

      :host.over {
        padding-bottom: 8rem;
      }

      :host.hidden {
        display: none;
      }

      :host.top {
        padding-top: 8rem;
      }

      :host.opacity{
        opacity: 0.8;
      }
    `;
    }
    handleMouseDown(e) {
        if (this.draggable) {
            this.checkLongPress(e);
        }
    }
    firstUpdated() {
        this.addEventListener('mouseleave', this.handleMouseLeave, false);
        this.addEventListener('mouseover', this.handleMouseOver, false);
        this.addEventListener('mouseup', this.handleMouseUp, false);
        this.addEventListener('mousemove', this.handleMouseMove, false);
    }
    disconnectedCallback() {
        this.removeEventListener('mouseleave', this.handleMouseLeave);
        this.removeEventListener('mouseover', this.handleMouseOver);
        this.removeEventListener('mouseup', this.handleMouseUp);
        this.addEventListener('mousemove', this.handleMouseMove);
    }
    render() {
        return html `
      <div class="left"><slot name="item-left"></slot></div>
      <div class="content"><slot name="item-content"></slot></div>
      <div class="right" @mousedown="${this.handleMouseDown}"><slot name="item-right"></slot></div>
    `;
    }
};
__decorate([
    property({ type: String, reflect: true })
], KaiItem.prototype, "mode", void 0);
__decorate([
    property({ type: Boolean, reflect: true })
], KaiItem.prototype, "button", void 0);
__decorate([
    property({ type: Boolean, reflect: true })
], KaiItem.prototype, "draggable", void 0);
KaiItem = __decorate([
    customElement('kai-item')
], KaiItem);
//# sourceMappingURL=kai-item.js.map