var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { customElement, LitElement, css, html, property } from 'lit-element';
import './kai-text';
import './kai-progress';
import { store } from '../services';
let KaiTabs = class KaiTabs extends LitElement {
    constructor() {
        super();
        this.cities = [];
        this.active = 0;
        this.isLoading = store.getState().config.isLoading;
        this.percentage = 0;
        this.panelScrollHandler = e => {
            const container = e.target;
            const panelWidth = window.innerWidth;
            const startPoint = panelWidth * this.active;
            const x = container.scrollLeft;
            const percentage = (x - startPoint) / panelWidth;
            if (percentage >= 0.5) {
                this.active += 1;
            }
            else if (percentage <= -0.5 && this.active > 0) {
                this.active -= 1;
            }
        };
        window.addEventListener('storechange', () => {
            this.isLoading = store.getState().config.isLoading;
        });
    }
    static get styles() {
        return css `
      :host {
        display: flex;
        flex-direction: column;
        width: 100%;
      }

      .tabs {
        display: flex;
        flex-flow: row nowrap;
        justify-content: center;
        align-items: flex-start;
        width: 100%;
        height: calc(var(--baseline) * 2.2);
        padding: calc(var(--baseline) * 0.7);
        overflow: hidden;
        white-space: nowrap;
        background-color: var(--gs-00);
      }

      .title {
        height: 7px;
        width: 7px;
        border-radius: 50%;
        padding: 2px 0;
        margin-right: 7px;
        white-space: nowrap;
        position: relative;
        transition-property: color;
        transition-duration: 0.12s;
        border: solid 1px var(--gs-100);
      }

      .title.-active {
        transition-duration: 0.2s;
        background-color: var(--gs-100);
      }

      .title::after {
        content: '';
        position: absolute;
        top: 100%;
        left: 10px;
        width: calc(100% - 20px);
        height: 3px;
        border-radius: 2px;
        background-color: var(--theme-color-primary);
        transition-property: transform, opacity;
        transition-duration: 0.3s, 0.15s;
        transition-timing-function: cubic-bezier(0.2, 0, 0.25, 1);
        transform: scaleX(0);
        opacity: 0;
      }

      .title:first-of-type::after,
      .title:last-of-type::after {
        width: calc(100% - 30px);
      }

      .title:first-of-type::after {
        left: 20px;
      }

      .title:only-child::after {
        width: calc(100% - 40px);
      }

      .title.-active::after {
        transform: scaleX(1);
        opacity: 1;
      }

      .panels {
        width: 36rem;
        height: calc(100% - 4rem);
        overflow-x: hidden;
        overflow-y: hidden;
        white-space: nowrap;
        scroll-snap-points-x: repeat(100%);
        scroll-snap-type: mandatory;
        scroll-behavior: smooth;
        font-size: 0;
        transition: height 0.24s cubic-bezier(0.5, 0, 1, 1);
      }
    `;
    }
    get currentTab() {
        return this.shadowRoot.querySelector('.tabs .title.-active');
    }
    get panelsContainer() {
        return this.shadowRoot.querySelector('.panels');
    }
    scrollPanel(index) {
        const panelWidth = window.innerWidth;
        const left = panelWidth * index;
        setTimeout(() => this.panelsContainer.scrollTo({
            left,
            behavior: 'smooth',
        }), 400);
    }
    async firstUpdated() {
        await super.updateComplete;
        await this.updateComplete;
        this.scrollPanel(this.active);
    }
    customEvent(old) {
        return new CustomEvent(`tab-change`, {
            bubbles: true,
            composed: true,
            cancelable: false,
            detail: {
                active: this.active,
                old,
            },
        });
    }
    async updated(changes) {
        const old = changes.get('active');
        if (changes.has('active')) {
            await super.updateComplete;
            await this.updateComplete;
            setTimeout(() => {
                this.dispatchEvent(this.customEvent(old));
            }, 300);
        }
    }
    renderTitles() {
        if (this.cities.length === 0) {
            return html `
        <header class="tabs">
          <div class="title -active" data-index="0"></div>
        </header>
      `;
        }
        return html `
      <header class="tabs">
        ${this.cities.map((title, index) => html `
            <div
              class="${index === this.active ? 'title -active' : 'title'}"
              data-index="${index}"
            ></div>
          `)}
      </header>
    `;
    }
    render() {
        return html `
      <kai-progress
        style="${this.isLoading ? '' : 'visibility: hidden'}"
        percentage="${this.percentage}"
        id="determinate"
      ></kai-progress>
      ${this.renderTitles()}
      <section class="panels">
        <slot></slot>
      </section>
    `;
    }
};
__decorate([
    property({ type: Array, reflect: true })
], KaiTabs.prototype, "titles", void 0);
__decorate([
    property({ type: Array })
], KaiTabs.prototype, "cities", void 0);
__decorate([
    property({ type: Number })
], KaiTabs.prototype, "active", void 0);
__decorate([
    property({ type: Boolean })
], KaiTabs.prototype, "isLoading", void 0);
__decorate([
    property({ type: Number, reflect: true })
], KaiTabs.prototype, "percentage", void 0);
KaiTabs = __decorate([
    customElement('kai-tabs')
], KaiTabs);
//# sourceMappingURL=kai-tabs.js.map