var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { LitElement, html, property, css, customElement } from 'lit-element';
const slideInKeyframes = [
    {
        transform: `translate(${window.innerWidth}px, 0)`,
        'z-index': 0,
        opacity: 1,
    },
    {
        transform: 'translate(0,0)',
        'z-index': 1,
        opacity: 1,
    },
];
const slideOutKeyframes = [
    {
        transform: 'translate(0,0)',
        'z-index': 1,
        opacity: 1,
    },
    {
        transform: `translate(${window.innerWidth}px, 0)`,
        'z-index': 0,
        opacity: 1,
    },
];
const fadeOutKeyframes = [
    {
        transform: 'scale(1)',
        opacity: 1,
        'z-index': 1,
    },
    {
        transform: 'scale(0.85)',
        opacity: 0,
        'z-index': 0,
    },
];
const fadeInKeyframes = [
    {
        transform: 'scale(0.85)',
        opacity: 0,
        'z-index': 0,
    },
    {
        transform: 'scale(1)',
        opacity: 1,
        'z-index': 1,
    },
];
let AppRouter = class AppRouter extends LitElement {
    constructor() {
        super();
        this.reverse = false;
        this.history = [];
        this.handleBackPage = (e) => {
            if (this.history.length === 1)
                return;
            const exiting = this.history.pop();
            const back = this.history[this.history.length - 1];
            if (e.detail.props) {
                back.props = Object.assign({}, back.props, e.detail.props);
            }
            const backPage = this.mountPage(back);
            this.shadowRoot.appendChild(backPage);
            this.exiting = exiting.id;
            this.entering = back.id;
            this.reverse = true;
        };
        this.handleChangePage = (e) => {
            const route = Object.assign({}, e.detail);
            const exiting = route.replace ? this.history.pop() : this.history[this.history.length - 1];
            const page = this.mountPage(route);
            this.shadowRoot.appendChild(page);
            delete route.replace;
            this.history.push(route);
            this.exiting = exiting.id;
            this.entering = route.id;
            this.reverse = false;
        };
        window.addEventListener('backpage', this.handleBackPage);
        window.addEventListener('changepage', this.handleChangePage);
        window.addEventListener('replacepage', this.handleChangePage);
    }
    static get styles() {
        return css `
      :host {
        width: 100%;
        height: 100%;
        overflow: hidden;
      }
    `;
    }
    mountPage(route) {
        const page = document.createElement(route.tag);
        page.id = route.id;
        if (route.props) {
            this.applyProps(page, route.props);
        }
        return page;
    }
    applyProps(page, props) {
        const keys = Object.keys(props);
        keys.forEach(key => {
            page.setAttribute(key.toLowerCase(), JSON.stringify(props[key]));
        });
    }
    findPage(id) {
        return this.shadowRoot.getElementById(id);
    }
    closePage(page) {
        const animation = this.reverse ? this.slideOut(page) : this.fadeOut(page);
        animation.onfinish = () => {
            this.shadowRoot.removeChild(page);
        };
    }
    openPage(page) {
        !this.reverse && page.setAttribute('style', `transform: translate(${window.innerWidth}px, 0);`);
        const animation = this.reverse ? this.fadeIn(page) : this.slideIn(page);
        animation.onfinish = () => {
            page.removeAttribute('style');
        };
    }
    slideIn(page) {
        return page.animate(slideInKeyframes, {
            delay: 120,
            duration: 300,
            easing: 'cubic-bezier(0,0,0.25,1)',
            fill: 'forwards',
        });
    }
    fadeIn(page) {
        return page.animate(fadeInKeyframes, {
            delay: 120,
            duration: 300,
            easing: 'cubic-bezier(0,0,0.25,1)',
            fill: 'forwards',
        });
    }
    fadeOut(page) {
        return page.animate(fadeOutKeyframes, {
            duration: 300,
            easing: 'cubic-bezier(0.5,0,1,1)',
            fill: 'forwards',
        });
    }
    slideOut(page) {
        return page.animate(slideOutKeyframes, {
            delay: 120,
            duration: 240,
            easing: 'cubic-bezier(0.5,0,1,1)',
            fill: 'forwards',
        });
    }
    firstUpdated() {
        const homePage = this.mountPage(this.home);
        homePage.slot = 'current';
        this.shadowRoot.appendChild(homePage);
        this.history.push(this.home);
    }
    updated(changes) {
        if (changes.has('entering')) {
            const oldPage = this.findPage(this.exiting);
            const newPage = this.findPage(this.entering);
            oldPage && this.closePage(oldPage);
            newPage && this.openPage(newPage);
        }
    }
    render() {
        return html ``;
    }
};
__decorate([
    property({ type: Object })
], AppRouter.prototype, "home", void 0);
__decorate([
    property({ type: Boolean })
], AppRouter.prototype, "reverse", void 0);
__decorate([
    property({ type: String })
], AppRouter.prototype, "exiting", void 0);
__decorate([
    property({ type: String })
], AppRouter.prototype, "entering", void 0);
__decorate([
    property({ type: Array })
], AppRouter.prototype, "history", void 0);
AppRouter = __decorate([
    customElement('app-router')
], AppRouter);
export { AppRouter };
//# sourceMappingURL=router.js.map